Nabuur volunteer opportunities | Volunteer in Bukavu DR of the Congo
Author: Nabuur
Description: 1001 Online volunteering opportunities. Everyone has something important to offer. We need you. Check it out at NABUUR.COM!
Keywords: Volunteer, Volunteering, Online volunteer opportunities, Nabuur

|  |  | Home | | |  | | |  | | | what can I do? | | |  | | |  |

Bukavu Home»Africa»DR of the Congo»Bukavu»Issue
| Issue | Stories & Photos | Neighbours | What´s new |
Bukavu: Women and young girls victims of violence
The context of war which characterized the city of Bukavu during several years has caused a procession of violence of all kinds. Its principal victims have been women and young girls. The large number of women and girls that fell victim to violence, rape, prostitution and abandonment is a big issue in the community. Read more...
Help Bukavu Join as an online volunteer
Amina Gisèle Local Representative | Focus: Setting up a Women Trauma and Care Centre
100 women have united in ?Women Against Violence?. Their ambition is to start a Women Trauma and Care Centre. The Centre will assist women victims of violence and abuse. It will give them a space where they can see hope again, know about their health, learn self-help skills and help each other campaign for their rights. Read more...
Maria Samper Facilitator contact | Here´s what YOU can do
Contact organizations that can provide our village with useful information to create a good project proposal and that could guide us on how to establish a succesful trauma center.
» | See the results of earlier actions
» | Subscribe to the Bukavu newsletter

Volunteering in : Africa - Asia - America
About NABUUR.COM - What can I do? - Policy - FAQ - Contact - Sitemap - Home
NABUUR.COM - Online Volunteering